Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'qa/qa/specs/helpers/quarantine.rb')
-rw-r--r--qa/qa/specs/helpers/quarantine.rb4
1 files changed, 3 insertions, 1 deletions
diff --git a/qa/qa/specs/helpers/quarantine.rb b/qa/qa/specs/helpers/quarantine.rb
index 738c99efb28..e58d70fdfb5 100644
--- a/qa/qa/specs/helpers/quarantine.rb
+++ b/qa/qa/specs/helpers/quarantine.rb
@@ -10,8 +10,10 @@ module QA
extend self
# Skip tests in quarantine unless we explicitly focus on them.
def skip_or_run_quarantined_tests_or_contexts(example)
+ return if Runtime::Env.quarantine_disabled?
+
if filters.key?(:quarantine)
included_filters = filters_other_than_quarantine
@@ -10,8 +10,10 @@ module QA
extend self
- # Skip tests in quarantine unless we explicitly focus on them.
+ # Skip tests in quarantine unless we explicitly focus on them or quarantine disabled
def skip_or_run_quarantined_tests_or_contexts(example)